@@ -149,7 +149,7 @@ calc_min_width (HTMLObject *self,
 
 	widget = HTML_EMBEDDED (self)->widget;
 
-	if (widget == NULL || !GTK_WIDGET_VISIBLE (widget))
+	if (widget == NULL || !gtk_widget_get_visible (widget))
 		return 0;
 
 	requisition.width = requisition.height = 0;
