@@ -140,9 +140,13 @@ html_engine_select_interval (HTMLEngine *e, HTMLInterval *i)
 {
 	e = html_engine_get_top_html_engine (e);
 	html_engine_hide_cursor (e);
-	if (e->selection && html_interval_eq (e->selection, i))
+	if (e->selection && html_interval_eq (e->selection, i)) {
 		html_interval_destroy (i);
-	else {
+	} else if (i && i->from.object == i->to.object && i->from.offset == i->to.offset) {
+		/* shouldn't select zero letters */
+		html_interval_destroy (i);
+		html_engine_unselect_all (e);
+	} else {
 		if (!e->selection || !optimize_selection (e, i)) {
 			html_engine_unselect_all (e);
 			e->selection = i;
@@ -399,7 +403,11 @@ html_engine_activate_selection (HTMLEngine *e, guint32 time)
 {
 	/* printf ("activate selection\n"); */
 
+#if GTK_CHECK_VERSION(2,19,7)
+	if (e->selection && e->block_selection == 0 && gtk_widget_get_realized (GTK_WIDGET (e->widget))) {
+#else
 	if (e->selection && e->block_selection == 0 && GTK_WIDGET_REALIZED (e->widget)) {
+#endif
 		gtk_selection_owner_set (GTK_WIDGET (e->widget), GDK_SELECTION_PRIMARY, time);
 		/* printf ("activated (%u).\n", time); */
 		clear_primary (e);
